==> libfwbuilder_0.10.4.orig.tar.gz: libfwbuilder-0.10.4.orig/src/fwbuilder/ObjectGroup.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 Vadim Kurland

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: ObjectGroup.cc,v 1.3 2001/12/19 12:46:59 lord Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/ObjectGroup.hh>
#include <fwbuilder/FWObjectReference.hh>

using namespace std;
using namespace libfwbuilder;

const char *ObjectGroup::TYPENAME={"ObjectGroup"};

ObjectGroup::ObjectGroup() : Group() {}

ObjectGroup::~ObjectGroup() {}

bool ObjectGroup::validateChild(FWObject *o)
{ 
    string otype=o->getTypeName();
    return (FWObject::validateChild(o) && 
	    (otype=="Host" || 
	     otype=="Network" || 
	     otype=="Firewall" ||
	     otype=="ObjectGroup" ||
	     otype=="ObjectRef"));
}

FWReference* ObjectGroup::createRef( FWObject* obj )
{
    return new FWObjectReference(obj);
}

==> libfwbuilder-1.0.2.tar.gz: libfwbuilder-1.0.2/src/fwbuilder/ObjectGroup.cc <==
/* 

                          Firewall Builder

                 Copyright (C) 2000 NetCitadel, LLC

  Author:  Vadim Kurland     vadim@vk.crocodile.org

  $Id: ObjectGroup.cc,v 1.10 2002/08/29 00:34:09 vkurland Exp $


  This program is free software which we release under the GNU General Public
  License. You may redistribute and/or modify this program under the terms
  of that license as published by the Free Software Foundation; either
  version 2 of the License, or (at your option) any later version.

  This program is distributed in the hope that it will be useful,
  but WITHOUT ANY WARRANTY; without even the implied warranty of
  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
  GNU General Public License for more details.
 
  To get a copy of the GNU General Public License, write to the Free Software
  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

*/


#include <fwbuilder/ObjectGroup.hh>
#include <fwbuilder/FWObjectReference.hh>
#include <fwbuilder/Address.hh>
#include <fwbuilder/AddressRange.hh>

using namespace std;
using namespace libfwbuilder;

const char *ObjectGroup::TYPENAME={"ObjectGroup"};

ObjectGroup::ObjectGroup() : Group() {}
ObjectGroup::ObjectGroup(const FWObject *root) : Group(root) {}

ObjectGroup::~ObjectGroup() {}

bool ObjectGroup::validateChild(FWObject *o)
{ 
    string otype=o->getTypeName();

    return (FWObject::validateChild(o) && 
	    (Address::cast(o)!=NULL || 
	     AddressRange::cast(o)!=NULL ||
	     ObjectGroup::cast(o)!=NULL ||
	     FWObjectReference::cast(o)!=NULL ));
}
